@@ -1,77 +1,33 @@
-`brierScore.ensembleBMAnormal` <-
+brierScore.ensembleBMAnormal <-
 function(fit, ensembleData, thresholds, dates = NULL, ...) 
 {
+#
+# copyright 2006-present, University of Washington. All rights reserved.
+# for terms of use, see the LICENSE file
+#
  weps <- 1.e-4
  
  matchITandFH(fit,ensembleData)
 
- M <- matchEnsembleMembers(fit,ensembleData)
- nForecasts <- ensembleSize(ensembleData)
- if (!all(M == 1:nForecasts)) ensembleData <- ensembleData[,M]
+ ensembleData <- ensembleData[,matchEnsembleMembers(fit,ensembleData)]
 
-# remove instances missing all forecasts, obs, or dates
+ M <- !dataNA(ensembleData)
+ if (!all(M)) ensembleData <- ensembleData[M,]
 
- M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
- M <- M | is.na(ensembleVerifObs(ensembleData))
- M <- M | is.na(ensembleValidDates(ensembleData))
- ensembleData <- ensembleData[!M,]
- 
- if (is.null(y <- ensembleVerifObs(ensembleData)))
-   stop("verification observations required")
-## remove instances missing all forecasts
+ fitDates <- modelDates(fit)
 
- M <- apply(ensembleForecasts(ensembleData), 1, function(z) all(is.na(z)))
- M <- M | is.na(ensembleVerifObs(ensembleData))
- ensembleData <- ensembleData[!M,]
- 
-## match specified dates with dateTable in fit
+ M <- matchDates( fitDates, ensembleValidDates(ensembleData), dates)
 
- dateTable <- dimnames(fit$weights)[[2]]
+ if (!all(M$ens)) ensembleData <- ensembleData[M$ens,]
+ if (!all(M$fit)) fit <- fit[fitDates[M$fit]]
 
- if (!is.null(dates)) {
+ dates <- modelDates(fit)
 
-   dates <- sort(unique(as.character(dates)))
+ Dates <- ensembleValidDates(ensembleData)
 
-   if (length(dates) > length(dateTable)) 
-     stop("parameters not available for some dates")
+ y <- dataVerifObs(ensembleData)
+ nObs <- length(y)
 
-   K <- match( dates, dateTable, nomatch=0)
-
-   if (any(!K) || !length(K)) 
-     stop("parameters not available for some dates")
-
- }
- else {
-
-   dates <- dateTable
-   K <- 1:length(dateTable)
-
-  }
-
- ensDates <- ensembleValidDates(ensembleData)
-
-## match dates in data with dateTable
- if (is.null(ensDates) || all(is.na(ensDates))) {
-   if (length(dates) > 1) stop("date ambiguity")
-   nObs <- nrow(ensembleData)
-   Dates <- rep( dates, nObs)
- }
- else {
-## remove instances missing dates
-   if (any(M <- is.na(ensDates))) {
-     ensembleData <- ensembleData[!M,]
-     ensDates <- ensembleValidDates(ensembleData)
-   }
-   Dates <- as.character(ensDates)
-   L <- as.logical(match( Dates, dates, nomatch=0))
-   if (all(!L) || !length(L)) 
-     stop("model fit dates incompatible with ensemble data")
-   Dates <- Dates[L]
-   ensembleData <- ensembleData[L,]
-   nObs <- length(Dates)
- }
-
- y <- ensembleVerifObs(ensembleData)
  nForecasts <- ensembleSize(ensembleData) 
 
  ensembleData <- ensembleForecasts(ensembleData)
@@ -95,15 +51,14 @@ function(fit, ensembleData, thresholds, dates = NULL, ...)
 # BMA Brier Scores
 
     l <- l + 1
-    k <- K[l]
 
-    WEIGHTS <- fit$weights[,k]
+    WEIGHTS <- fit$weights[,d]
     if (all(Wmiss <- is.na(WEIGHTS))) next
      
     SD <- if (!is.null(dim(fit$sd))) {
-            fit$sd[,k] 
+            fit$sd[,d] 
           }
-         else rep(fit$sd[k], nForecasts)
+         else rep(fit$sd[d], nForecasts)
 
     I <- which(as.logical(match(Dates, d, nomatch = 0)))
 
@@ -113,7 +68,7 @@ function(fit, ensembleData, thresholds, dates = NULL, ...)
 
        M <- is.na(f) | Wmiss
      
-       MEAN <- apply(rbind(1, f) * fit$biasCoefs[,,k], 2, sum)
+       MEAN <- apply(rbind(1, f) * fit$biasCoefs[,,d], 2, sum)
 
        W <- WEIGHTS
        if (any(M)) { 
