@@ -5,7 +5,8 @@ function (YYYYMMDDHH)
 # copyright 2006-present, University of Washington. All rights reserved.
 # for terms of use, see the LICENSE file
 #
- if (!exists("chron")) library("chron")
+# require("chron")
+
  YYYYMMDDHH <- sapply(YYYYMMDDHH, as.character)
  l <- sapply(YYYYMMDDHH, nchar)
  if (any(I <- (l > 10 | l == 9 | l < 8))) stop("invalid date string")
